/* --------------------------------------------------------------- */
/* pri2Debug.c -- debug device I/O functions                       */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/* The debug functions communicate with the host computer using a  */
/* serial link over a USB Virtual COM port.                        */
/*                                                                 */
/* For primer2, this is via the "STM32" USB connection.            */
/*                                                                 */
/* Note that on Windows a driver must be installed for this to     */
/* work; this should be automatic (using Internet search).         */
/*                                                                 */
/* --------------------------------------------------------------- */

#define  TOLLOS_IO            // allow use of I/O functions
#include "tollos.h"

/* --------------------------------------------------------------- */
/* debugGetcIO -- get character                                    */
/*                                                                 */
/*   returns character read from host, or -1 if none there         */
/*                                                                 */
/* This function does not block.                                   */
/* --------------------------------------------------------------- */
int debugGetcIO(void) {       // get character
  return vcomGetcIO();
  } // debugGetcIO

/* --------------------------------------------------------------- */
/* debugInitIO -- initialize port for I/O                          */
/*                                                                 */
/*   baud -- rate to run debug communications                      */
/*                                                                 */
/* The baud rate is ignored because this is a Virtual COM port.    */
/* --------------------------------------------------------------- */
void debugInitIO(uint baud) {
  nop((int)baud);             // ignore baud

  // pull down USB_DISCONNECT
  bitSet(PORTD, BIT3, BIT_OFF);

  vcomInitIO();
  // note: the debug interface does not report an error during Init

  } // debugInitIO


/* --------------------------------------------------------------- */
/* debugPutcIO -- send character to debug terminal                 */
/*                                                                 */
/*   ch -- character to send                                       */
/*                                                                 */
/* This does not block; if too many characters are sent they will  */
/* be quietly discarded.                                           */
/* --------------------------------------------------------------- */
void debugPutcIO(int ch) {     // send character
  vcomPutcIO(ch);
  } // debugPutcIO

